function S = mspecgramz(s, B, Bs, Z, varargin)
% MSPECGRAM Compute zeropadded spectrogram
% SPECTROGRAM = MSPECGRAM(SIGNAL, BLOCK_SIZE, BLOCK_SKIP, ZEROPAD)
% Computes the spectrogram of the data in SIGNAL.
%
% SPECTROGRAM = MSPECGRAM(SIGNAL, BLOCK_SIZE, BLOCK_SKIP, ZEROPAD, 
%    NUMBER_OF_BLOCKS)
% Computes the spectrogram for a specified number of blocks.

if nargin>=5
    nB = varargin{1};
else
    nB = floor((length(s)-B)/Bs)+1;
end

kpoints = ceil(1+(B+Z)/2);
S = zeros(kpoints, nB);
w = hanning(B);
for b = 1:nB
    x = [w.*s(Bs*(b-1)+(1:B)); zeros(Z,1)];
    X = fft(x);
    S(:,b) = X(1:kpoints);
end